@@ -37,7 +37,7 @@ class AboutDialog(Gtk.AboutDialog):
         self.set_transient_for(parent)
         self.set_authors(("Osmo Salomaa <otsaloma@iki.fi>",))
         self.set_comments(_("Viewer for NFO files"))
-        self.set_copyright("Copyright © 2005–2016 Osmo Salomaa")
+        self.set_copyright("Copyright © 2005–2017 Osmo Salomaa")
         self.set_license_type(Gtk.License.GPL_3_0)
         self.set_logo_icon_name("nfoview")
         # TRANSLATORS: The application name "NFO Viewer" has been intentionally
@@ -53,6 +53,16 @@ class AboutDialog(Gtk.AboutDialog):
         # lines seperated by newlines (\n).
         self.set_translator_credits(_("translator-credits"))
         self.set_version(nfoview.__version__)
-        self.set_website("http://otsaloma.io/nfoview/")
+        self.set_website("https://otsaloma.io/nfoview/")
         self.set_website_label(_("NFO Viewer Website"))
         self.set_wrap_license(True)
+        with nfoview.util.silent(Exception, tb=True):
+            # Add donate button to the bottom of the dialog.
+            # This can fail if the dialog structure changes.
+            box = self.get_content_area()
+            button = Gtk.LinkButton(label=_("Donate"))
+            button.set_uri("https://www.paypal.me/otsaloma")
+            button.show()
+            box.pack_start(button, expand=False, fill=False, padding=0)
+            switcher = self.get_header_bar().get_children()[0]
+            switcher.get_children()[0].grab_focus()
